"use strict";

var _myF = _interopRequireDefault(require("@antv/my-f2"));

var _methods = _interopRequireDefault(require("../mixins/methods"));

var _util = _interopRequireDefault(require("../util"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var BLUE = '#1890ff';
var TEXTBLUE = '#1890FF';

function render(chart, props, width, height) {
  var series = props.series,
      xAxis = props.xAxis,
      yAxis = props.yAxis,
      tooltip = props.tooltip,
      grid = props.grid;
  chart.clear();
  var data = [];

  if (series.length === 1) {
    series[0].data.forEach(function (item) {
      item.type = series[0].type;
    });
    data = series[0].data;
  } else if (series.length > 1) {
    series.forEach(function (item, i) {
      item.data.forEach(function (item2) {
        item2.type = item.type || i;
      });
      data = data.concat(item.data);
    });
  }

  chart.source(data); // 开始配置坐标轴

  chart.axis('key', {
    label: function label(text) {
      return {
        text: text + ' ' + series[0].xExtAlias // 格式化坐标轴显示文本

      };
    },
    grid: grid ? {
      stroke: '#d9d9d9',
      lineWidth: 1,
      lineDash: [2, 2]
    } : null
  });
  chart.axis('value', {
    line: _myF.default.Util.mix({}, _myF.default.Global._defaultAxis.line, {
      top: false
    }),
    label: function label(text) {
      if (text > 0) {
        return {
          text: text + ' ' + series[0].yExtAlias
        };
      }
    }
  }); //配置坐标轴的伸长比

  if (xAxis) {
    if (xAxis.htAlign) {
      xAxis.label = _util.default.label;
    }

    chart.scale('key', _util.default.scale(xAxis));
  }

  if (yAxis) {
    chart.scale('value', _util.default.scale(yAxis));
  } //ToolTip 展示desc和x，y坐标


  if (tooltip) {
    chart.tooltip(Object.assign(tooltip, {
      onShow: function onChange(ev) {
        var items = ev.items;
        items[0].title = items[0].origin.desc;
        items[0].name = 'x ' + items[0].origin.key;
        items[0].value = 'y ' + items[0].origin.value;
      }
    }));
  } //绘制气泡，半径范围[10,40],气泡颜色跟随设置中的颜色或者默认BLUE颜色


  chart.point().position('key*value').color(series[0].color || BLUE).size('size', [10, 40]).shape('circle').style({
    lineWidth: 1,
    stroke: series[0].color || BLUE,
    opacity: 0.3
  }); //绘制辅助文本，文本颜色跟随设置中的颜色或者默认文本TEXTBLUE颜色

  data.map(function (item) {
    chart.guide().text({
      position: [item.key, item.value],
      content: item.name,
      style: {
        textAlign: 'center',
        textBaseline: 'middle',
        fill: series[0].color || TEXTBLUE
      }
    });
  });
  chart.changeSize(width, height);
}

Component({
  mixins: [_methods.default],
  props: {
    series: [],
    tooltip: {
      showTitle: true,
      showItemMarker: false,
      crosshairsType: 'xy',
      offsetY: 10
    }
  },
  didMount: function didMount() {
    var _this = this;

    my.call('getStartupParams', {}, function (result) {
      _util.default.tracert('bubble', result.appId, result.url);
    });
    var id = "am-mc-bubble-".concat(this.$id);
    var ctx = this.ctx = my.createCanvasContext(id);
    var canvas = this.canvas = new _myF.default.Renderer(ctx);
    var pixelRatio = this.pixelRatio = my.getSystemInfoSync().pixelRatio;
    ctx.scale(pixelRatio, pixelRatio);
    my.createSelectorQuery().select("#".concat(id)).boundingClientRect().exec(function (res) {
      if (!res || !res.length || !res[0]) {
        return;
      }

      var _res$ = res[0],
          width = _res$.width,
          height = _res$.height;

      _this.setData({
        width: width * pixelRatio,
        height: height * pixelRatio
      }, function () {
        var _this$props = _this.props,
            padding = _this$props.padding,
            appendPadding = _this$props.appendPadding;
        _this.chart = new _myF.default.Chart({
          el: canvas,
          width: width,
          height: height,
          padding: padding,
          appendPadding: appendPadding
        });
        render(_this.chart, _this.props, width, height);
      });
    });
  },
  didUpdate: function didUpdate() {
    var _this2 = this;

    var id = "am-mc-bubble-".concat(this.$id);
    var pixelRatio = this.pixelRatio;
    my.createSelectorQuery().select("#".concat(id)).boundingClientRect().exec(function (res) {
      if (!res || !res.length || !res[0]) {
        return;
      }

      var _res$2 = res[0],
          width = _res$2.width,
          height = _res$2.height;

      if (_this2.data.width !== width * pixelRatio || _this2.data.height !== height * pixelRatio) {
        _this2.ctx.scale(pixelRatio, pixelRatio);
      }

      _this2.setData({
        width: width * pixelRatio,
        height: height * pixelRatio
      }, function () {
        render(_this2.chart, _this2.props, width, height);
      });
    });
  }
});