"use strict";

var _myF = _interopRequireDefault(require("@antv/my-f2"));

var _methods = _interopRequireDefault(require("../mixins/methods"));

var _util = _interopRequireDefault(require("../util"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function render(chart, props, width, height) {
  var series = props.series,
      xAxis = props.xAxis,
      yAxis = props.yAxis,
      tooltip = props.tooltip,
      guide = props.guide;
  chart.clear();
  var data = series.map(function (item) {
    return Object.assign({}, item, {
      range: [item.start, item.end, item.max, item.min],
      trend: item.start <= item.end ? 0 : 1
    });
  });
  chart.source(data);

  if (xAxis) {
    if (xAxis.htAlign) {
      xAxis.label = _util.default.label;
    }

    chart.scale('time', _util.default.scale(xAxis));
    chart.axis('time', _util.default.axis(xAxis));
  }

  if (yAxis) {
    chart.scale('range', _util.default.scale(yAxis));
    chart.axis('range', _util.default.axis(yAxis));
  }

  chart.tooltip(tooltip);
  chart.legend(false);
  chart.schema().position('time*range').color('trend', function (trend) {
    return ['#F4333C', '#1CA93D'][trend];
  }).shape('candle');

  if (guide) {
    if (guide.line) {
      chart.guide().line(guide.line);
    }

    if (guide.text) {
      chart.guide().text(guide.text);
    }
  }

  chart.changeSize(width, height);
}

Component({
  mixins: [_methods.default],
  props: {
    categories: [],
    series: [],
    xAxis: {
      tickCount: 3
    },
    yAxis: {
      tickCount: 3
    },
    tooltip: false
  },
  didMount: function didMount() {
    var _this = this;

    my.call('getStartupParams', {}, function (result) {
      _util.default.tracert('k', result.appId, result.url);
    });
    var id = "am-mc-k-".concat(this.$id);
    var ctx = this.ctx = my.createCanvasContext(id);
    var canvas = this.canvas = new _myF.default.Renderer(ctx);
    var pixelRatio = this.pixelRatio = my.getSystemInfoSync().pixelRatio;
    ctx.scale(pixelRatio, pixelRatio);
    my.createSelectorQuery().select("#".concat(id)).boundingClientRect().exec(function (res) {
      if (!res || !res.length || !res[0]) {
        return;
      }

      var _res$ = res[0],
          width = _res$.width,
          height = _res$.height;

      _this.setData({
        width: width * pixelRatio,
        height: height * pixelRatio
      }, function () {
        var _this$props = _this.props,
            padding = _this$props.padding,
            appendPadding = _this$props.appendPadding;
        _this.chart = new _myF.default.Chart({
          el: canvas,
          width: width,
          height: height,
          padding: padding,
          appendPadding: appendPadding
        });
        render(_this.chart, _this.props, width, height);
      });
    });
  },
  didUpdate: function didUpdate() {
    var _this2 = this;

    var id = "am-mc-k-".concat(this.$id);
    var pixelRatio = this.pixelRatio;
    my.createSelectorQuery().select("#".concat(id)).boundingClientRect().exec(function (res) {
      if (!res || !res.length || !res[0]) {
        return;
      }

      var _res$2 = res[0],
          width = _res$2.width,
          height = _res$2.height;

      if (_this2.data.width !== width * pixelRatio || _this2.data.height !== height * pixelRatio) {
        _this2.ctx.scale(pixelRatio, pixelRatio);
      }

      _this2.setData({
        width: width * pixelRatio,
        height: height * pixelRatio
      }, function () {
        render(_this2.chart, _this2.props, width, height);
      });
    });
  }
});