"use strict";

var _myF = _interopRequireDefault(require("@antv/my-f2"));

var _methods = _interopRequireDefault(require("../mixins/methods"));

var _util = _interopRequireDefault(require("../util"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function render(chart, props, width, height) {
  var series = props.series,
      legend = props.legend,
      style = props.style,
      radius = props.radius,
      innerRadius = props.innerRadius,
      tooltip = props.tooltip,
      guide = props.guide,
      cascade = props.cascade,
      pieLabel = props.pieLabel,
      sidePadding = props.sidePadding,
      activeShape = props.activeShape;
  chart.clear();
  var data = cascade ? series : series.map(function (item) {
    item.key = 'key';
    return item;
  });
  chart.source(data);
  chart.coord('polar', {
    transposed: true,
    innerRadius: innerRadius,
    radius: radius || 1
  });

  if (pieLabel) {
    // 添加饼图文本
    chart.pieLabel({
      sidePadding: sidePadding,
      activeShape: activeShape,
      label1: function label1(data, color) {
        return {
          text: data.type,
          fill: color
        };
      },
      label2: function label2(data, color) {
        return {
          text: data.data,
          fill: color,
          fontWeight: 'bold'
        };
      }
    });
  }

  var color = [];
  var dftColors = _myF.default.Global.colors;
  var length = dftColors.length;
  series.forEach(function (kind, i) {
    color.push(kind.color || dftColors[i % length]);
  });
  chart.axis(false);
  chart.tooltip(tooltip);
  chart.legend(legend);
  chart.interval().position('key*data').color('type', color).adjust('stack').style(style);

  if (guide) {
    if (guide.text) {
      chart.guide().text(guide.text);
    }
  }

  chart.changeSize(width, height);
}

Component({
  mixins: [_methods.default],
  props: {
    series: [],
    radius: 1,
    innerRadius: 0,
    cascade: false,
    pieLabel: false,
    sidePadding: 40,
    tooltip: false,
    legend: false
  },
  didMount: function didMount() {
    var _this = this;

    my.call('getStartupParams', {}, function (result) {
      _util.default.tracert('pie', result.appId, result.url);
    });
    var id = "am-mc-pie-".concat(this.$id);
    var ctx = this.ctx = my.createCanvasContext(id);
    var canvas = this.canvas = new _myF.default.Renderer(ctx);
    var pixelRatio = this.pixelRatio = my.getSystemInfoSync().pixelRatio;
    ctx.scale(pixelRatio, pixelRatio);
    my.createSelectorQuery().select("#".concat(id)).boundingClientRect().exec(function (res) {
      if (!res || !res.length || !res[0]) {
        return;
      }

      var _res$ = res[0],
          width = _res$.width,
          height = _res$.height;

      _this.setData({
        width: width * pixelRatio,
        height: height * pixelRatio
      }, function () {
        var _this$props = _this.props,
            padding = _this$props.padding,
            appendPadding = _this$props.appendPadding;
        _this.chart = new _myF.default.Chart({
          el: canvas,
          width: width,
          height: height,
          padding: padding,
          appendPadding: appendPadding
        });
        render(_this.chart, _this.props, width, height);
      });
    });
  },
  didUpdate: function didUpdate() {
    var _this2 = this;

    var id = "am-mc-pie-".concat(this.$id);
    var pixelRatio = this.pixelRatio;
    my.createSelectorQuery().select("#".concat(id)).boundingClientRect().exec(function (res) {
      if (!res || !res.length || !res[0]) {
        return;
      }

      var _res$2 = res[0],
          width = _res$2.width,
          height = _res$2.height;

      if (_this2.data.width !== width * pixelRatio || _this2.data.height !== height * pixelRatio) {
        _this2.ctx.scale(pixelRatio, pixelRatio);
      }

      _this2.setData({
        width: width * pixelRatio,
        height: height * pixelRatio
      }, function () {
        render(_this2.chart, _this2.props, width, height);
      });
    });
  }
});