"use strict";

var _myF = _interopRequireDefault(require("@antv/my-f2"));

var _methods = _interopRequireDefault(require("../mixins/methods"));

var _util = _interopRequireDefault(require("../util"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function render(chart, props, width, height) {
  var categories = props.categories,
      series = props.series,
      yAxis = props.yAxis,
      tooltip = props.tooltip,
      legend = props.legend;
  chart.clear();
  var data = [];

  if (series.length === 1) {
    data = series[0].data.map(function (item, i) {
      return {
        key: categories[i],
        value: item
      };
    });
  } else if (series.length > 1) {
    series.forEach(function (kind) {
      data = data.concat(kind.data.map(function (item, i) {
        return {
          key: categories[i],
          value: item,
          type: kind.type
        };
      }));
    });
  }

  chart.source(data);
  chart.coord('polar');

  if (yAxis) {
    chart.scale('value', _util.default.scale(yAxis));
    chart.axis('value', _util.default.axis(yAxis));
  }

  chart.tooltip(tooltip);
  chart.legend(legend);
  var style = {};
  series.forEach(function (kind) {
    style[kind.type] = kind.style;
  });
  var color = {};
  series.forEach(function (kind) {
    color[kind.type] = kind.color;
  });

  if (series.length === 1) {
    chart.area().position('key*value').color('type', function (type) {
      return color[type];
    }).shape('type', function (type) {
      return style[type] || 'line';
    });
    chart.line().position('key*value').color('type', function (type) {
      return color[type];
    }).shape('type', function (type) {
      return style[type] || 'line';
    });

    if (series[0].point) {
      chart.point().position('key*value').style(series[0].point);
    }
  } else if (series.length > 1) {
    chart.area().position('key*value').color('type', function (type) {
      return color[type];
    }).shape('type', function (type) {
      return style[type] || 'line';
    });
    chart.line().position('key*value').color('type', function (type) {
      return color[type];
    }).shape('type', function (type) {
      return style[type] || 'line';
    });
    var pointType = [];
    var pointStyle;
    series.forEach(function (kind) {
      if (kind.point) {
        pointType.push(kind.type);
        pointStyle = kind.point;
      }
    });

    if (pointType.length) {
      chart.point().position('key*value').color('type').size('type', function (v) {
        if (pointType.indexOf(v) === -1) {
          return 0;
        }
      }).style(pointStyle);
    }
  }

  chart.changeSize(width, height);
}

Component({
  mixins: [_methods.default],
  props: {
    categories: [],
    series: [],
    yAxis: {
      tickCount: 3
    },
    tooltip: false,
    legend: false
  },
  didMount: function didMount() {
    var _this = this;

    my.call('getStartupParams', {}, function (result) {
      _util.default.tracert('radar', result.appId, result.url);
    });
    var id = "am-mc-radar-".concat(this.$id);
    var ctx = this.ctx = my.createCanvasContext(id);
    var canvas = this.canvas = new _myF.default.Renderer(ctx);
    var pixelRatio = this.pixelRatio = my.getSystemInfoSync().pixelRatio;
    ctx.scale(pixelRatio, pixelRatio);
    my.createSelectorQuery().select("#".concat(id)).boundingClientRect().exec(function (res) {
      if (!res || !res.length) {
        return;
      }

      var _res$ = res[0],
          width = _res$.width,
          height = _res$.height;

      _this.setData({
        width: width * pixelRatio,
        height: height * pixelRatio
      }, function () {
        var _this$props = _this.props,
            padding = _this$props.padding,
            appendPadding = _this$props.appendPadding;
        _this.chart = new _myF.default.Chart({
          el: canvas,
          width: width,
          height: height,
          padding: padding,
          appendPadding: appendPadding
        });
        render(_this.chart, _this.props, width, height);
      });
    });
  },
  didUpdate: function didUpdate() {
    var _this2 = this;

    var id = "am-mc-radar-".concat(this.$id);
    var pixelRatio = this.pixelRatio;
    my.createSelectorQuery().select("#".concat(id)).boundingClientRect().exec(function (res) {
      if (!res || !res.length || !res[0]) {
        return;
      }

      var _res$2 = res[0],
          width = _res$2.width,
          height = _res$2.height;

      if (_this2.data.width !== width * pixelRatio || _this2.data.height !== height * pixelRatio) {
        _this2.ctx.scale(pixelRatio, pixelRatio);
      }

      _this2.setData({
        width: width * pixelRatio,
        height: height * pixelRatio
      }, function () {
        render(_this2.chart, _this2.props, width, height);
      });
    });
  }
});