"use strict";

var _myF = _interopRequireDefault(require("@antv/my-f2"));

var _methods = _interopRequireDefault(require("../mixins/methods"));

var _util = _interopRequireDefault(require("../util"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function render(chart, props, width, height) {
  var series = props.series,
      xAxis = props.xAxis,
      yAxis = props.yAxis,
      tooltip = props.tooltip,
      legend = props.legend,
      style = props.style;
  chart.clear();
  var data = [];

  if (series.length === 1) {
    series[0].data.forEach(function (item) {
      item.type = series[0].type;
    });
    data = series[0].data;
  } else if (series.length > 1) {
    series.forEach(function (item, i) {
      item.data.forEach(function (item2) {
        item2.type = item.type || i;
      });
      data = data.concat(item.data);
    });
  }

  chart.source(data);

  if (xAxis) {
    if (xAxis.htAlign) {
      xAxis.label = _util.default.label;
    }

    chart.scale('key', _util.default.scale(xAxis));
    chart.axis('key', _util.default.axis(xAxis));
  }

  if (yAxis) {
    chart.scale('value', _util.default.scale(yAxis));
    chart.axis('value', _util.default.axis(yAxis));
  }

  chart.tooltip(tooltip);
  chart.legend(legend);
  var color = [];
  var size = [];
  var dftColors = _myF.default.Global.colors;
  var length = dftColors.length;
  series.forEach(function (kind, i) {
    color.push(kind.color || dftColors[i % length]);
    size.push(kind.size || 3);
  });
  chart.point().position('key*value').color('type', color).size('type', size).style(style);
  chart.changeSize(width, height);
}

Component({
  mixins: [_methods.default],
  props: {
    series: [],
    tooltip: false,
    legend: false
  },
  didMount: function didMount() {
    var _this = this;

    my.call('getStartupParams', {}, function (result) {
      _util.default.tracert('scatter', result.appId, result.url);
    });
    var id = "am-mc-scatter-".concat(this.$id);
    var ctx = this.ctx = my.createCanvasContext(id);
    var canvas = this.canvas = new _myF.default.Renderer(ctx);
    var pixelRatio = this.pixelRatio = my.getSystemInfoSync().pixelRatio;
    ctx.scale(pixelRatio, pixelRatio);
    my.createSelectorQuery().select("#".concat(id)).boundingClientRect().exec(function (res) {
      if (!res || !res.length || !res[0]) {
        return;
      }

      var _res$ = res[0],
          width = _res$.width,
          height = _res$.height;

      _this.setData({
        width: width * pixelRatio,
        height: height * pixelRatio
      }, function () {
        var _this$props = _this.props,
            padding = _this$props.padding,
            appendPadding = _this$props.appendPadding;
        _this.chart = new _myF.default.Chart({
          el: canvas,
          width: width,
          height: height,
          padding: padding,
          appendPadding: appendPadding
        });
        render(_this.chart, _this.props, width, height);
      });
    });
  },
  didUpdate: function didUpdate() {
    var _this2 = this;

    var id = "am-mc-scatter-".concat(this.$id);
    var pixelRatio = this.pixelRatio;
    my.createSelectorQuery().select("#".concat(id)).boundingClientRect().exec(function (res) {
      if (!res || !res.length || !res[0]) {
        return;
      }

      var _res$2 = res[0],
          width = _res$2.width,
          height = _res$2.height;

      if (_this2.data.width !== width * pixelRatio || _this2.data.height !== height * pixelRatio) {
        _this2.ctx.scale(pixelRatio, pixelRatio);
      }

      _this2.setData({
        width: width * pixelRatio,
        height: height * pixelRatio
      }, function () {
        render(_this2.chart, _this2.props, width, height);
      });
    });
  }
});